@@ -31,7 +31,7 @@ struct _ValaCCodeConstantPrivate {
 #define VALA_CCODE_CONSTANT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CONSTANT, ValaCCodeConstantPrivate))
 enum  {
 	VALA_CCODE_CONSTANT_DUMMY_PROPERTY,
-	VALA_CCODE_CONSTANT_NAME,
+	VALA_CCODE_CONSTANT_NAME
 };
 static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_constant_parent_class = NULL;
@@ -40,18 +40,22 @@ static void vala_ccode_constant_dispose (GObject * obj);
 
 ValaCCodeConstant* vala_ccode_constant_new (const char* _name)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeConstant * self;
 	g_return_val_if_fail (_name != NULL, NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	ValaCCodeConstant * self = g_object_newv (VALA_TYPE_CCODE_CONSTANT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_CONSTANT, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeConstant * self = VALA_CCODE_CONSTANT (base);
+	ValaCCodeConstant * self;
+	self = VALA_CCODE_CONSTANT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, vala_ccode_constant_get_name (self));
 }
@@ -66,15 +70,17 @@ char* vala_ccode_constant_get_name (ValaCCodeConstant* self)
 
 void vala_ccode_constant_set_name (ValaCCodeConstant* self, const char* value)
 {
+	char* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_CONSTANT (self));
-	char* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
 }
 
 
 static void vala_ccode_constant_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeConstant * self = VALA_CCODE_CONSTANT (object);
+	ValaCCodeConstant * self;
+	self = VALA_CCODE_CONSTANT (object);
 	switch (property_id) {
 		case VALA_CCODE_CONSTANT_NAME:
 		g_value_set_string (value, vala_ccode_constant_get_name (self));
@@ -85,7 +91,8 @@ static void vala_ccode_constant_get_property (GObject * object, guint property_i
 
 static void vala_ccode_constant_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeConstant * self = VALA_CCODE_CONSTANT (object);
+	ValaCCodeConstant * self;
+	self = VALA_CCODE_CONSTANT (object);
 	switch (property_id) {
 		case VALA_CCODE_CONSTANT_NAME:
 		vala_ccode_constant_set_name (self, g_value_get_string (value));
@@ -114,10 +121,11 @@ static void vala_ccode_constant_init (ValaCCodeConstant * self)
 
 static void vala_ccode_constant_dispose (GObject * obj)
 {
-	ValaCCodeConstant * self = VALA_CCODE_CONSTANT (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	ValaCCodeConstant * self;
 	ValaCCodeConstantClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_CONSTANT (obj);
+	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	klass = VALA_CCODE_CONSTANT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_CONSTANT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
