@@ -75,25 +75,11 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 			ValaCCodeNode* node;
 			node = node_it->data;
 			{
-				vala_ccode_node_write_declaration (node, writer);
+				vala_ccode_node_write_combined (node, writer);
 			}
 		}
 		(__temp0 == NULL ? NULL : (__temp0 = (g_list_free (__temp0), NULL)));
 	}
-	{
-		GList* __temp1;
-		GList* node_it;
-		__temp1 = NULL;
-		__temp1 = vala_ccode_fragment_get_children (VALA_CCODE_FRAGMENT (self));
-		for (node_it = __temp1; node_it != NULL; node_it = node_it->next) {
-			ValaCCodeNode* node;
-			node = node_it->data;
-			{
-				vala_ccode_node_write (node, writer);
-			}
-		}
-		(__temp1 == NULL ? NULL : (__temp1 = (g_list_free (__temp1), NULL)));
-	}
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "#endif");
 	vala_ccode_writer_write_newline (writer);
@@ -117,10 +103,10 @@ char* vala_ccode_once_section_get_define (ValaCCodeOnceSection* self)
 
 void vala_ccode_once_section_set_define (ValaCCodeOnceSection* self, const char* value)
 {
-	char* __temp3;
+	char* __temp2;
 	g_return_if_fail (VALA_IS_CCODE_ONCE_SECTION (self));
-	__temp3 = NULL;
-	self->priv->_define = (__temp3 = g_strdup (value), (self->priv->_define = (g_free (self->priv->_define), NULL)), __temp3);
+	__temp2 = NULL;
+	self->priv->_define = (__temp2 = g_strdup (value), (self->priv->_define = (g_free (self->priv->_define), NULL)), __temp2);
 }
 
 
