@@ -56,162 +56,201 @@ ValaCCodeCompiler* vala_ccode_compiler_new ()
  */
 void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* context)
 {
+	GError * inner_error;
 	char* pc;
+	char* __temp1;
 	char* pkgflags;
 	gint exit_status;
-	GError* err;
 	char* cmdline;
-	char* __temp7;
-	char* __temp6;
-	char* __temp13;
-	char* __temp12;
+	char* __temp9;
+	char* __temp8;
+	char* __temp15;
+	char* __temp14;
 	GList* source_files;
-	gboolean success;
 	g_return_if_fail (VALA_IS_CCODE_COMPILER (self));
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
+	inner_error = NULL;
 	pc = g_strdup ("pkg-config --cflags");
 	if (!vala_code_context_get_compile_only (context)) {
 		char* __temp0;
 		__temp0 = NULL;
 		pc = (__temp0 = g_strconcat (pc, (" --libs"), NULL), (pc = (g_free (pc), NULL)), __temp0);
 	}
+	__temp1 = NULL;
+	pc = (__temp1 = g_strconcat (pc, (" gobject-2.0"), NULL), (pc = (g_free (pc), NULL)), __temp1);
+	if (vala_code_context_get_thread (context)) {
+		char* __temp2;
+		__temp2 = NULL;
+		pc = (__temp2 = g_strconcat (pc, (" gthread-2.0"), NULL), (pc = (g_free (pc), NULL)), __temp2);
+	}
 	{
-		GList* __temp3;
+		GList* __temp5;
 		GList* pkg_it;
-		__temp3 = NULL;
-		__temp3 = vala_code_context_get_packages (context);
-		for (pkg_it = __temp3; pkg_it != NULL; pkg_it = pkg_it->next) {
+		__temp5 = NULL;
+		__temp5 = vala_code_context_get_packages (context);
+		for (pkg_it = __temp5; pkg_it != NULL; pkg_it = pkg_it->next) {
 			char* pkg;
 			pkg = pkg_it->data;
 			{
-				char* __temp2;
-				char* __temp1;
-				__temp2 = NULL;
-				__temp1 = NULL;
-				pc = (__temp2 = g_strconcat (pc, (__temp1 = (g_strconcat (" ", pkg, NULL))), NULL), (pc = (g_free (pc), NULL)), __temp2);
-				(__temp1 = (g_free (__temp1), NULL));
+				char* __temp4;
+				char* __temp3;
+				__temp4 = NULL;
+				__temp3 = NULL;
+				pc = (__temp4 = g_strconcat (pc, (__temp3 = (g_strconcat (" ", pkg, NULL))), NULL), (pc = (g_free (pc), NULL)), __temp4);
+				(__temp3 = (g_free (__temp3), NULL));
 			}
 		}
-		(__temp3 == NULL ? NULL : (__temp3 = (g_list_free (__temp3), NULL)));
+		(__temp5 == NULL ? NULL : (__temp5 = (g_list_free (__temp5), NULL)));
 	}
 	pkgflags = NULL;
 	exit_status = 0;
-	err = NULL;
-	if (!g_spawn_command_line_sync (pc, &pkgflags, NULL, &exit_status, &err)) {
-		vala_report_error (NULL, err->message);
-		(pc = (g_free (pc), NULL));
-		(pkgflags = (g_free (pkgflags), NULL));
-		(err == NULL ? NULL : (err = (g_error_free (err), NULL)));
-		return;
-	} else {
+	{
+		g_spawn_command_line_sync (pc, &pkgflags, NULL, &exit_status, &inner_error);
+		if (inner_error != NULL) {
+			if (inner_error->domain == G_SPAWN_ERROR) {
+				goto __catch0_g_spawn_error;
+			}
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+			g_clear_error (&inner_error);
+		}
 		if (exit_status != 0) {
-			char* __temp4;
-			__temp4 = NULL;
-			vala_report_error (NULL, (__temp4 = g_strdup_printf ("pkg-config exited with status %d", exit_status)));
-			(__temp4 = (g_free (__temp4), NULL));
+			char* __temp6;
+			__temp6 = NULL;
+			vala_report_error (NULL, (__temp6 = g_strdup_printf ("pkg-config exited with status %d", exit_status)));
+			(__temp6 = (g_free (__temp6), NULL));
 			(pc = (g_free (pc), NULL));
 			(pkgflags = (g_free (pkgflags), NULL));
-			(err == NULL ? NULL : (err = (g_error_free (err), NULL)));
 			return;
 		}
 	}
+	goto __finally0;
+	__catch0_g_spawn_error:
+	{
+		GError * e;
+		e = inner_error;
+		inner_error = NULL;
+		{
+			vala_report_error (NULL, e->message);
+			(pc = (g_free (pc), NULL));
+			(pkgflags = (g_free (pkgflags), NULL));
+			return;
+		}
+	}
+	__finally0:
+	;
 	/* TODO compile the C code files in parallel*/
 	cmdline = g_strdup ("cc");
 	if (vala_code_context_get_debug (context)) {
-		char* __temp5;
-		__temp5 = NULL;
-		cmdline = (__temp5 = g_strconcat (cmdline, (" -g"), NULL), (cmdline = (g_free (cmdline), NULL)), __temp5);
+		char* __temp7;
+		__temp7 = NULL;
+		cmdline = (__temp7 = g_strconcat (cmdline, (" -g"), NULL), (cmdline = (g_free (cmdline), NULL)), __temp7);
 	}
-	__temp7 = NULL;
-	__temp6 = NULL;
-	cmdline = (__temp7 = g_strconcat (cmdline, (__temp6 = (g_strdup_printf (" -O%d", vala_code_context_get_optlevel (context)))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp7);
-	(__temp6 = (g_free (__temp6), NULL));
+	__temp9 = NULL;
+	__temp8 = NULL;
+	cmdline = (__temp9 = g_strconcat (cmdline, (__temp8 = (g_strdup_printf (" -O%d", vala_code_context_get_optlevel (context)))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp9);
+	(__temp8 = (g_free (__temp8), NULL));
 	if (vala_code_context_get_compile_only (context)) {
-		char* __temp8;
-		__temp8 = NULL;
-		cmdline = (__temp8 = g_strconcat (cmdline, (" -c"), NULL), (cmdline = (g_free (cmdline), NULL)), __temp8);
+		char* __temp10;
+		__temp10 = NULL;
+		cmdline = (__temp10 = g_strconcat (cmdline, (" -c"), NULL), (cmdline = (g_free (cmdline), NULL)), __temp10);
 	} else {
 		if (vala_code_context_get_output (context) != NULL) {
+			char* __temp13;
+			char* __temp12;
 			char* __temp11;
-			char* __temp10;
-			char* __temp9;
+			__temp13 = NULL;
+			__temp12 = NULL;
 			__temp11 = NULL;
-			__temp10 = NULL;
-			__temp9 = NULL;
-			cmdline = (__temp11 = g_strconcat (cmdline, (__temp10 = (g_strconcat (" -o ", (__temp9 = g_shell_quote (vala_code_context_get_output (context))), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp11);
-			(__temp10 = (g_free (__temp10), NULL));
-			(__temp9 = (g_free (__temp9), NULL));
+			cmdline = (__temp13 = g_strconcat (cmdline, (__temp12 = (g_strconcat (" -o ", (__temp11 = g_shell_quote (vala_code_context_get_output (context))), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp13);
+			(__temp12 = (g_free (__temp12), NULL));
+			(__temp11 = (g_free (__temp11), NULL));
 		}
 	}
-	__temp13 = NULL;
-	__temp12 = NULL;
-	cmdline = (__temp13 = g_strconcat (cmdline, (__temp12 = (g_strconcat (" ", pkgflags, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp13);
-	(__temp12 = (g_free (__temp12), NULL));
+	__temp15 = NULL;
+	__temp14 = NULL;
+	cmdline = (__temp15 = g_strconcat (cmdline, (__temp14 = (g_strconcat (" ", pkgflags, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp15);
+	(__temp14 = (g_free (__temp14), NULL));
 	/* we're only interested in non-pkg source files */
 	source_files = vala_code_context_get_source_files (context);
 	{
-		GList* __temp18;
+		GList* __temp20;
 		GList* file_it;
-		__temp18 = NULL;
-		__temp18 = source_files;
-		for (file_it = __temp18; file_it != NULL; file_it = file_it->next) {
+		__temp20 = NULL;
+		__temp20 = source_files;
+		for (file_it = __temp20; file_it != NULL; file_it = file_it->next) {
 			ValaSourceFile* file;
 			file = file_it->data;
 			{
 				if (!vala_source_file_get_pkg (file)) {
+					char* __temp19;
+					char* __temp18;
 					char* __temp17;
 					char* __temp16;
-					char* __temp15;
-					char* __temp14;
+					__temp19 = NULL;
+					__temp18 = NULL;
 					__temp17 = NULL;
 					__temp16 = NULL;
-					__temp15 = NULL;
-					__temp14 = NULL;
-					cmdline = (__temp17 = g_strconcat (cmdline, (__temp16 = (g_strconcat (" ", (__temp15 = g_shell_quote ((__temp14 = vala_source_file_get_csource_filename (file)))), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp17);
+					cmdline = (__temp19 = g_strconcat (cmdline, (__temp18 = (g_strconcat (" ", (__temp17 = g_shell_quote ((__temp16 = vala_source_file_get_csource_filename (file)))), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp19);
+					(__temp18 = (g_free (__temp18), NULL));
+					(__temp17 = (g_free (__temp17), NULL));
 					(__temp16 = (g_free (__temp16), NULL));
-					(__temp15 = (g_free (__temp15), NULL));
-					(__temp14 = (g_free (__temp14), NULL));
 				}
 			}
 		}
 	}
-	success = g_spawn_command_line_sync (cmdline, NULL, NULL, &exit_status, &err);
 	{
-		GList* __temp21;
+		g_spawn_command_line_sync (cmdline, NULL, NULL, &exit_status, &inner_error);
+		if (inner_error != NULL) {
+			if (inner_error->domain == G_SPAWN_ERROR) {
+				goto __catch1_g_spawn_error;
+			}
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+			g_clear_error (&inner_error);
+		}
+		if (exit_status != 0) {
+			char* __temp21;
+			__temp21 = NULL;
+			vala_report_error (NULL, (__temp21 = g_strdup_printf ("cc exited with status %d", exit_status)));
+			(__temp21 = (g_free (__temp21), NULL));
+		}
+	}
+	goto __finally1;
+	__catch1_g_spawn_error:
+	{
+		GError * e;
+		e = inner_error;
+		inner_error = NULL;
+		{
+			vala_report_error (NULL, e->message);
+		}
+	}
+	__finally1:
+	;
+	{
+		GList* __temp24;
 		GList* file_it;
-		__temp21 = NULL;
-		__temp21 = source_files;
-		for (file_it = __temp21; file_it != NULL; file_it = file_it->next) {
+		__temp24 = NULL;
+		__temp24 = source_files;
+		for (file_it = __temp24; file_it != NULL; file_it = file_it->next) {
 			ValaSourceFile* file;
 			file = file_it->data;
 			{
 				/* remove generated C source and header files */
 				if (!vala_source_file_get_pkg (file)) {
-					char* __temp19;
-					char* __temp20;
-					__temp19 = NULL;
-					g_unlink ((__temp19 = vala_source_file_get_csource_filename (file)));
-					(__temp19 = (g_free (__temp19), NULL));
-					__temp20 = NULL;
-					g_unlink ((__temp20 = vala_source_file_get_cheader_filename (file)));
-					(__temp20 = (g_free (__temp20), NULL));
+					char* __temp22;
+					char* __temp23;
+					__temp22 = NULL;
+					g_unlink ((__temp22 = vala_source_file_get_csource_filename (file)));
+					(__temp22 = (g_free (__temp22), NULL));
+					__temp23 = NULL;
+					g_unlink ((__temp23 = vala_source_file_get_cheader_filename (file)));
+					(__temp23 = (g_free (__temp23), NULL));
 				}
 			}
 		}
 	}
-	if (!success) {
-		vala_report_error (NULL, err->message);
-	} else {
-		if (exit_status != 0) {
-			char* __temp22;
-			__temp22 = NULL;
-			vala_report_error (NULL, (__temp22 = g_strdup_printf ("cc exited with status %d", exit_status)));
-			(__temp22 = (g_free (__temp22), NULL));
-		}
-	}
 	(pc = (g_free (pc), NULL));
 	(pkgflags = (g_free (pkgflags), NULL));
-	(err == NULL ? NULL : (err = (g_error_free (err), NULL)));
 	(cmdline = (g_free (cmdline), NULL));
 	(source_files == NULL ? NULL : (source_files = (g_list_free (source_files), NULL)));
 }
