@@ -36,7 +36,7 @@ enum  {
 	VALA_BINARY_EXPRESSION_DUMMY_PROPERTY,
 	VALA_BINARY_EXPRESSION_OPERATOR,
 	VALA_BINARY_EXPRESSION_LEFT,
-	VALA_BINARY_EXPRESSION_RIGHT,
+	VALA_BINARY_EXPRESSION_RIGHT
 };
 static void vala_binary_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_binary_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
@@ -55,23 +55,27 @@ static void vala_binary_expression_dispose (GObject * obj);
  */
 ValaBinaryExpression* vala_binary_expression_new (ValaBinaryOperator op, ValaExpression* _left, ValaExpression* _right, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaBinaryExpression * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (_left), NULL);
 	g_return_val_if_fail (VALA_IS_EXPRESSION (_right), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 4);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 4);
+	__params_it = __params;
 	(__params_it->name = "operator", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, op), __params_it++);
 	(__params_it->name = "left", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _left), __params_it++);
 	(__params_it->name = "right", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _right), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaBinaryExpression * self = g_object_newv (VALA_TYPE_BINARY_EXPRESSION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_BINARY_EXPRESSION, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_binary_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaBinaryExpression * self = VALA_BINARY_EXPRESSION (base);
+	ValaBinaryExpression * self;
+	self = VALA_BINARY_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_binary_expression_get_left (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_binary_expression_get_right (self)), visitor);
@@ -81,7 +85,8 @@ static void vala_binary_expression_real_accept (ValaCodeNode* base, ValaCodeVisi
 
 static void vala_binary_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
-	ValaBinaryExpression * self = VALA_BINARY_EXPRESSION (base);
+	ValaBinaryExpression * self;
+	self = VALA_BINARY_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_binary_expression_get_left (self)) == old_node) {
@@ -116,8 +121,9 @@ ValaExpression* vala_binary_expression_get_left (ValaBinaryExpression* self)
 
 void vala_binary_expression_set_left (ValaBinaryExpression* self, ValaExpression* value)
 {
+	ValaExpression* __temp2;
 	g_return_if_fail (VALA_IS_BINARY_EXPRESSION (self));
-	ValaExpression* __temp2 = NULL;
+	__temp2 = NULL;
 	self->priv->_left = (__temp2 = g_object_ref (value), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), __temp2);
 	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_left), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_left)));
 }
@@ -132,8 +138,9 @@ ValaExpression* vala_binary_expression_get_right (ValaBinaryExpression* self)
 
 void vala_binary_expression_set_right (ValaBinaryExpression* self, ValaExpression* value)
 {
+	ValaExpression* __temp4;
 	g_return_if_fail (VALA_IS_BINARY_EXPRESSION (self));
-	ValaExpression* __temp4 = NULL;
+	__temp4 = NULL;
 	self->priv->_right = (__temp4 = g_object_ref (value), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), __temp4);
 	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_right), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_right)));
 }
@@ -141,7 +148,8 @@ void vala_binary_expression_set_right (ValaBinaryExpression* self, ValaExpressio
 
 static void vala_binary_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaBinaryExpression * self = VALA_BINARY_EXPRESSION (object);
+	ValaBinaryExpression * self;
+	self = VALA_BINARY_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_BINARY_EXPRESSION_OPERATOR:
 		g_value_set_int (value, vala_binary_expression_get_operator (self));
@@ -158,7 +166,8 @@ static void vala_binary_expression_get_property (GObject * object, guint propert
 
 static void vala_binary_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaBinaryExpression * self = VALA_BINARY_EXPRESSION (object);
+	ValaBinaryExpression * self;
+	self = VALA_BINARY_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_BINARY_EXPRESSION_OPERATOR:
 		vala_binary_expression_set_operator (self, g_value_get_int (value));
@@ -196,11 +205,12 @@ static void vala_binary_expression_init (ValaBinaryExpression * self)
 
 static void vala_binary_expression_dispose (GObject * obj)
 {
-	ValaBinaryExpression * self = VALA_BINARY_EXPRESSION (obj);
-	(self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL)));
-	(self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL)));
+	ValaBinaryExpression * self;
 	ValaBinaryExpressionClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_BINARY_EXPRESSION (obj);
+	(self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL)));
+	(self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL)));
 	klass = VALA_BINARY_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_BINARY_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
