@@ -36,6 +36,7 @@ struct _ValaCodeNodePrivate {
 	ValaSymbol* _symbol;
 	ValaSourceReference* _source_reference;
 	gboolean _error;
+	gboolean _tree_can_fail;
 	ValaCCodeNode* _ccodenode;
 };
 #define VALA_CODE_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CODE_NODE, ValaCodeNodePrivate))
@@ -45,7 +46,8 @@ enum  {
 	VALA_CODE_NODE_SYMBOL,
 	VALA_CODE_NODE_SOURCE_REFERENCE,
 	VALA_CODE_NODE_CCODENODE,
-	VALA_CODE_NODE_ERROR
+	VALA_CODE_NODE_ERROR,
+	VALA_CODE_NODE_TREE_CAN_FAIL
 };
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
@@ -250,6 +252,20 @@ void vala_code_node_set_error (ValaCodeNode* self, gboolean value)
 }
 
 
+gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self)
+{
+	g_return_val_if_fail (VALA_IS_CODE_NODE (self), FALSE);
+	return self->priv->_tree_can_fail;
+}
+
+
+void vala_code_node_set_tree_can_fail (ValaCodeNode* self, gboolean value)
+{
+	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	self->priv->_tree_can_fail = value;
+}
+
+
 static void vala_code_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
 	ValaCodeNode * self;
@@ -270,6 +286,9 @@ static void vala_code_node_get_property (GObject * object, guint property_id, GV
 		case VALA_CODE_NODE_ERROR:
 		g_value_set_boolean (value, vala_code_node_get_error (self));
 		break;
+		case VALA_CODE_NODE_TREE_CAN_FAIL:
+		g_value_set_boolean (value, vala_code_node_get_tree_can_fail (self));
+		break;
 	}
 }
 
@@ -294,6 +313,9 @@ static void vala_code_node_set_property (GObject * object, guint property_id, co
 		case VALA_CODE_NODE_ERROR:
 		vala_code_node_set_error (self, g_value_get_boolean (value));
 		break;
+		case VALA_CODE_NODE_TREE_CAN_FAIL:
+		vala_code_node_set_tree_can_fail (self, g_value_get_boolean (value));
+		break;
 	}
 }
 
@@ -314,6 +336,7 @@ static void vala_code_node_class_init (ValaCodeNodeClass * klass)
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_SOURCE_REFERENCE, g_param_spec_object ("source-reference", "foo", "bar", VALA_TYPE_SOURCE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_CCODENODE, g_param_spec_object ("ccodenode", "foo", "bar", VALA_TYPE_CCODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_ERROR, g_param_spec_boolean ("error", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_TREE_CAN_FAIL, g_param_spec_boolean ("tree-can-fail", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
