@@ -23,7 +23,6 @@
 
 #ifndef __VALACODEVISITOR_H__
 #define __VALACODEVISITOR_H__
-typedef struct _ValaCodeVisitorPrivate ValaCodeVisitorPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -39,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_CODE_VISITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_VISITOR))
 #define VALA_CODE_VISITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorClass))
 
+typedef struct _ValaCodeVisitorPrivate ValaCodeVisitorPrivate;
 
 /**
  * Abstract code node visitor for traversing source code tree.
@@ -96,12 +96,9 @@ struct _ValaCodeVisitorClass {
 	void (*visit_continue_statement) (ValaCodeVisitor* self, ValaContinueStatement* stmt);
 	void (*visit_begin_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 	void (*visit_end_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-	void (*visit_begin_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-	void (*visit_end_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-	void (*visit_begin_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
-	void (*visit_end_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
-	void (*visit_begin_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
-	void (*visit_end_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
+	void (*visit_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
+	void (*visit_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
+	void (*visit_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
 	void (*visit_lock_statement) (ValaCodeVisitor* self, ValaLockStatement* stmt);
 	void (*visit_begin_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 	void (*visit_end_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
@@ -185,12 +182,9 @@ void vala_code_visitor_visit_break_statement (ValaCodeVisitor* self, ValaBreakSt
 void vala_code_visitor_visit_continue_statement (ValaCodeVisitor* self, ValaContinueStatement* stmt);
 void vala_code_visitor_visit_begin_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 void vala_code_visitor_visit_end_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-void vala_code_visitor_visit_begin_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-void vala_code_visitor_visit_end_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-void vala_code_visitor_visit_begin_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
-void vala_code_visitor_visit_end_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
-void vala_code_visitor_visit_begin_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
-void vala_code_visitor_visit_end_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
+void vala_code_visitor_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
+void vala_code_visitor_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
+void vala_code_visitor_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
 void vala_code_visitor_visit_lock_statement (ValaCodeVisitor* self, ValaLockStatement* stmt);
 void vala_code_visitor_visit_begin_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 void vala_code_visitor_visit_end_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
