@@ -32,6 +32,7 @@
 #include <vala/valaattribute.h>
 
 struct _ValaEnumPrivate {
+	gboolean _error_domain;
 	GList* values;
 	GList* methods;
 	char* cname;
@@ -41,7 +42,8 @@ struct _ValaEnumPrivate {
 };
 #define VALA_ENUM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ENUM, ValaEnumPrivate))
 enum  {
-	VALA_ENUM_DUMMY_PROPERTY
+	VALA_ENUM_DUMMY_PROPERTY,
+	VALA_ENUM_ERROR_DOMAIN
 };
 static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -361,6 +363,10 @@ void vala_enum_process_attributes (ValaEnum* self)
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_enum_process_ccode_attribute (self, a);
+				} else {
+					if (g_utf8_collate (vala_attribute_get_name (a), "ErrorDomain") == 0) {
+						(vala_enum_set_error_domain (self, TRUE), vala_enum_get_error_domain (self));
+					}
 				}
 			}
 		}
@@ -409,10 +415,50 @@ static char* vala_enum_real_get_default_value (ValaDataType* base)
 }
 
 
+gboolean vala_enum_get_error_domain (ValaEnum* self)
+{
+	g_return_val_if_fail (VALA_IS_ENUM (self), FALSE);
+	return self->priv->_error_domain;
+}
+
+
+void vala_enum_set_error_domain (ValaEnum* self, gboolean value)
+{
+	g_return_if_fail (VALA_IS_ENUM (self));
+	self->priv->_error_domain = value;
+}
+
+
+static void vala_enum_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+{
+	ValaEnum * self;
+	self = VALA_ENUM (object);
+	switch (property_id) {
+		case VALA_ENUM_ERROR_DOMAIN:
+		g_value_set_boolean (value, vala_enum_get_error_domain (self));
+		break;
+	}
+}
+
+
+static void vala_enum_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
+{
+	ValaEnum * self;
+	self = VALA_ENUM (object);
+	switch (property_id) {
+		case VALA_ENUM_ERROR_DOMAIN:
+		vala_enum_set_error_domain (self, g_value_get_boolean (value));
+		break;
+	}
+}
+
+
 static void vala_enum_class_init (ValaEnumClass * klass)
 {
 	vala_enum_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaEnumPrivate));
+	G_OBJECT_CLASS (klass)->get_property = vala_enum_get_property;
+	G_OBJECT_CLASS (klass)->set_property = vala_enum_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_enum_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_enum_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_enum_real_accept_children;
@@ -426,6 +472,7 @@ static void vala_enum_class_init (ValaEnumClass * klass)
 	VALA_DATA_TYPE_CLASS (klass)->get_get_value_function = vala_enum_real_get_get_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_set_value_function = vala_enum_real_get_set_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_default_value = vala_enum_real_get_default_value;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ENUM_ERROR_DOMAIN, g_param_spec_boolean ("error-domain", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
