@@ -1,6 +1,6 @@
 /* valalocalvariabledeclaration.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,7 +36,7 @@ struct _ValaLocalVariableDeclarationPrivate {
 #define VALA_LOCAL_VARIABLE_DECLARATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_LOCAL_VARIABLE_DECLARATION, ValaLocalVariableDeclarationPrivate))
 enum  {
 	VALA_LOCAL_VARIABLE_DECLARATION_DUMMY_PROPERTY,
-	VALA_LOCAL_VARIABLE_DECLARATION_TYPE_REFERENCE,
+	VALA_LOCAL_VARIABLE_DECLARATION_TYPE_REFERENCE
 };
 static void vala_local_variable_declaration_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_local_variable_declaration_parent_class = NULL;
@@ -52,13 +52,16 @@ static void vala_local_variable_declaration_dispose (GObject * obj);
  */
 ValaLocalVariableDeclaration* vala_local_variable_declaration_new (ValaTypeReference* type, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaLocalVariableDeclaration * self;
 	g_return_val_if_fail (type == NULL || VALA_IS_TYPE_REFERENCE (type), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaLocalVariableDeclaration * self = g_object_newv (VALA_TYPE_LOCAL_VARIABLE_DECLARATION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_LOCAL_VARIABLE_DECLARATION, __params_it - __params, __params);
 	return self;
 }
 
@@ -73,11 +76,14 @@ ValaLocalVariableDeclaration* vala_local_variable_declaration_new (ValaTypeRefer
  */
 ValaLocalVariableDeclaration* vala_local_variable_declaration_new_var_type (ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaLocalVariableDeclaration * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaLocalVariableDeclaration * self = g_object_newv (VALA_TYPE_LOCAL_VARIABLE_DECLARATION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_LOCAL_VARIABLE_DECLARATION, __params_it - __params, __params);
 	return self;
 }
 
@@ -110,17 +116,20 @@ GList* vala_local_variable_declaration_get_variable_declarators (ValaLocalVariab
 
 static void vala_local_variable_declaration_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaLocalVariableDeclaration * self = VALA_LOCAL_VARIABLE_DECLARATION (base);
+	ValaLocalVariableDeclaration * self;
+	self = VALA_LOCAL_VARIABLE_DECLARATION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_local_variable_declaration_get_type_reference (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_local_variable_declaration_get_type_reference (self)), visitor);
 	}
 	{
-		GList* __temp1 = NULL;
-		__temp1 = self->priv->variable_declarators;
+		GList* __temp1;
 		GList* decl_it;
+		__temp1 = NULL;
+		__temp1 = self->priv->variable_declarators;
 		for (decl_it = __temp1; decl_it != NULL; decl_it = decl_it->next) {
-			ValaVariableDeclarator* decl = decl_it->data;
+			ValaVariableDeclarator* decl;
+			decl = decl_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (decl), visitor);
 			}
@@ -139,16 +148,19 @@ ValaTypeReference* vala_local_variable_declaration_get_type_reference (ValaLocal
 
 void vala_local_variable_declaration_set_type_reference (ValaLocalVariableDeclaration* self, ValaTypeReference* value)
 {
+	ValaTypeReference* __temp4;
+	ValaTypeReference* __temp3;
 	g_return_if_fail (VALA_IS_LOCAL_VARIABLE_DECLARATION (self));
-	ValaTypeReference* __temp4 = NULL;
-	ValaTypeReference* __temp3 = NULL;
+	__temp4 = NULL;
+	__temp3 = NULL;
 	self->priv->_type_reference = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_object_ref (__temp3))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp4);
 }
 
 
 static void vala_local_variable_declaration_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaLocalVariableDeclaration * self = VALA_LOCAL_VARIABLE_DECLARATION (object);
+	ValaLocalVariableDeclaration * self;
+	self = VALA_LOCAL_VARIABLE_DECLARATION (object);
 	switch (property_id) {
 		case VALA_LOCAL_VARIABLE_DECLARATION_TYPE_REFERENCE:
 		g_value_set_object (value, vala_local_variable_declaration_get_type_reference (self));
@@ -159,7 +171,8 @@ static void vala_local_variable_declaration_get_property (GObject * object, guin
 
 static void vala_local_variable_declaration_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaLocalVariableDeclaration * self = VALA_LOCAL_VARIABLE_DECLARATION (object);
+	ValaLocalVariableDeclaration * self;
+	self = VALA_LOCAL_VARIABLE_DECLARATION (object);
 	switch (property_id) {
 		case VALA_LOCAL_VARIABLE_DECLARATION_TYPE_REFERENCE:
 		vala_local_variable_declaration_set_type_reference (self, g_value_get_object (value));
@@ -188,11 +201,12 @@ static void vala_local_variable_declaration_init (ValaLocalVariableDeclaration *
 
 static void vala_local_variable_declaration_dispose (GObject * obj)
 {
-	ValaLocalVariableDeclaration * self = VALA_LOCAL_VARIABLE_DECLARATION (obj);
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
-	(self->priv->variable_declarators == NULL ? NULL : (self->priv->variable_declarators = (g_list_foreach (self->priv->variable_declarators, (GFunc) g_object_unref, NULL), g_list_free (self->priv->variable_declarators), NULL)));
+	ValaLocalVariableDeclaration * self;
 	ValaLocalVariableDeclarationClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_LOCAL_VARIABLE_DECLARATION (obj);
+	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
+	(self->priv->variable_declarators == NULL ? NULL : (self->priv->variable_declarators = (g_list_foreach (self->priv->variable_declarators, (GFunc) g_object_unref, NULL), g_list_free (self->priv->variable_declarators), NULL)));
 	klass = VALA_LOCAL_VARIABLE_DECLARATION_CLASS (g_type_class_peek (VALA_TYPE_LOCAL_VARIABLE_DECLARATION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
