@@ -65,6 +65,9 @@ static void vala_memory_manager_real_visit_named_argument (ValaCodeVisitor* base
 static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl);
 static void vala_memory_manager_real_visit_expression_statement (ValaCodeVisitor* base, ValaExpressionStatement* stmt);
 static void vala_memory_manager_real_visit_end_return_statement (ValaCodeVisitor* base, ValaReturnStatement* stmt);
+static void vala_memory_manager_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt);
+static void vala_memory_manager_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt);
+static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause);
 static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr);
 static void vala_memory_manager_real_visit_end_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr);
 static void vala_memory_manager_real_visit_binary_expression (ValaCodeVisitor* base, ValaBinaryExpression* expr);
@@ -290,6 +293,33 @@ static void vala_memory_manager_real_visit_end_return_statement (ValaCodeVisitor
 }
 
 
+static void vala_memory_manager_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt)
+{
+	ValaMemoryManager * self;
+	self = VALA_MEMORY_MANAGER (base);
+	g_return_if_fail (VALA_IS_THROW_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_memory_manager_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt)
+{
+	ValaMemoryManager * self;
+	self = VALA_MEMORY_MANAGER (base);
+	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause)
+{
+	ValaMemoryManager * self;
+	self = VALA_MEMORY_MANAGER (base);
+	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
+	vala_code_node_accept_children (VALA_CODE_NODE (clause), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr)
 {
 	ValaMemoryManager * self;
@@ -635,6 +665,9 @@ static void vala_memory_manager_class_init (ValaMemoryManagerClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_variable_declarator = vala_memory_manager_real_visit_variable_declarator;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_expression_statement = vala_memory_manager_real_visit_expression_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_end_return_statement = vala_memory_manager_real_visit_end_return_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_throw_statement = vala_memory_manager_real_visit_throw_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_memory_manager_real_visit_try_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_memory_manager_real_visit_catch_clause;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member_access = vala_memory_manager_real_visit_member_access;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_end_invocation_expression = vala_memory_manager_real_visit_end_invocation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_binary_expression = vala_memory_manager_real_visit_binary_expression;
