@@ -23,9 +23,6 @@
 
 #ifndef __VALAMEMORYMANAGER_H__
 #define __VALAMEMORYMANAGER_H__
-typedef struct _ValaMemoryManager ValaMemoryManager;
-typedef struct _ValaMemoryManagerClass ValaMemoryManagerClass;
-typedef struct _ValaMemoryManagerPrivate ValaMemoryManagerPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -48,6 +45,9 @@ typedef struct _ValaMemoryManagerPrivate ValaMemoryManagerPrivate;
 #include <vala/valavariabledeclarator.h>
 #include <vala/valaexpressionstatement.h>
 #include <vala/valareturnstatement.h>
+#include <vala/valathrowstatement.h>
+#include <vala/valatrystatement.h>
+#include <vala/valacatchclause.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valainvocationexpression.h>
 #include <vala/valabinaryexpression.h>
@@ -63,6 +63,9 @@ G_BEGIN_DECLS
 #define VALA_IS_MEMORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMORY_MANAGER))
 #define VALA_MEMORY_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMORY_MANAGER, ValaMemoryManagerClass))
 
+typedef struct _ValaMemoryManager ValaMemoryManager;
+typedef struct _ValaMemoryManagerClass ValaMemoryManagerClass;
+typedef struct _ValaMemoryManagerPrivate ValaMemoryManagerPrivate;
 
 /**
  * Code visitor analyzing memory usage. The memory manager finds leaked and
