@@ -33,7 +33,7 @@ struct _ValaParenthesizedExpressionPrivate {
 #define VALA_PARENTHESIZED_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PARENTHESIZED_EXPRESSION, ValaParenthesizedExpressionPrivate))
 enum  {
 	VALA_PARENTHESIZED_EXPRESSION_DUMMY_PROPERTY,
-	VALA_PARENTHESIZED_EXPRESSION_INNER,
+	VALA_PARENTHESIZED_EXPRESSION_INNER
 };
 static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_parenthesized_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
@@ -50,20 +50,24 @@ static void vala_parenthesized_expression_dispose (GObject * obj);
  */
 ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression* _inner, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaParenthesizedExpression * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _inner), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaParenthesizedExpression * self = g_object_newv (VALA_TYPE_PARENTHESIZED_EXPRESSION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_PARENTHESIZED_EXPRESSION, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaParenthesizedExpression * self = VALA_PARENTHESIZED_EXPRESSION (base);
+	ValaParenthesizedExpression * self;
+	self = VALA_PARENTHESIZED_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_parenthesized_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_parenthesized_expression (visitor, self);
@@ -72,7 +76,8 @@ static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaC
 
 static void vala_parenthesized_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
-	ValaParenthesizedExpression * self = VALA_PARENTHESIZED_EXPRESSION (base);
+	ValaParenthesizedExpression * self;
+	self = VALA_PARENTHESIZED_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_parenthesized_expression_get_inner (self)) == old_node) {
@@ -90,8 +95,9 @@ ValaExpression* vala_parenthesized_expression_get_inner (ValaParenthesizedExpres
 
 void vala_parenthesized_expression_set_inner (ValaParenthesizedExpression* self, ValaExpression* value)
 {
+	ValaExpression* __temp1;
 	g_return_if_fail (VALA_IS_PARENTHESIZED_EXPRESSION (self));
-	ValaExpression* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
 	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_inner)));
 }
@@ -99,7 +105,8 @@ void vala_parenthesized_expression_set_inner (ValaParenthesizedExpression* self,
 
 static void vala_parenthesized_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaParenthesizedExpression * self = VALA_PARENTHESIZED_EXPRESSION (object);
+	ValaParenthesizedExpression * self;
+	self = VALA_PARENTHESIZED_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_PARENTHESIZED_EXPRESSION_INNER:
 		g_value_set_object (value, vala_parenthesized_expression_get_inner (self));
@@ -110,7 +117,8 @@ static void vala_parenthesized_expression_get_property (GObject * object, guint
 
 static void vala_parenthesized_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaParenthesizedExpression * self = VALA_PARENTHESIZED_EXPRESSION (object);
+	ValaParenthesizedExpression * self;
+	self = VALA_PARENTHESIZED_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_PARENTHESIZED_EXPRESSION_INNER:
 		vala_parenthesized_expression_set_inner (self, g_value_get_object (value));
@@ -140,10 +148,11 @@ static void vala_parenthesized_expression_init (ValaParenthesizedExpression * se
 
 static void vala_parenthesized_expression_dispose (GObject * obj)
 {
-	ValaParenthesizedExpression * self = VALA_PARENTHESIZED_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
+	ValaParenthesizedExpression * self;
 	ValaParenthesizedExpressionClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_PARENTHESIZED_EXPRESSION (obj);
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	klass = VALA_PARENTHESIZED_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_PARENTHESIZED_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
