@@ -34,7 +34,7 @@ struct _ValaReturnStatementPrivate {
 #define VALA_RETURN_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_RETURN_STATEMENT, ValaReturnStatementPrivate))
 enum  {
 	VALA_RETURN_STATEMENT_DUMMY_PROPERTY,
-	VALA_RETURN_STATEMENT_RETURN_EXPRESSION,
+	VALA_RETURN_STATEMENT_RETURN_EXPRESSION
 };
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_return_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
@@ -51,20 +51,24 @@ static void vala_return_statement_dispose (GObject * obj);
  */
 ValaReturnStatement* vala_return_statement_new (ValaExpression* result, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaReturnStatement * self;
 	g_return_val_if_fail (result == NULL || VALA_IS_EXPRESSION (result), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "return-expression", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, result), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaReturnStatement * self = g_object_newv (VALA_TYPE_RETURN_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_RETURN_STATEMENT, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaReturnStatement * self = VALA_RETURN_STATEMENT (base);
+	ValaReturnStatement * self;
+	self = VALA_RETURN_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_begin_return_statement (visitor, self);
 	if (vala_return_statement_get_return_expression (self) != NULL) {
@@ -77,7 +81,8 @@ static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisit
 
 static void vala_return_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
-	ValaReturnStatement * self = VALA_RETURN_STATEMENT (base);
+	ValaReturnStatement * self;
+	self = VALA_RETURN_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_return_statement_get_return_expression (self)) == old_node) {
@@ -95,9 +100,11 @@ ValaExpression* vala_return_statement_get_return_expression (ValaReturnStatement
 
 void vala_return_statement_set_return_expression (ValaReturnStatement* self, ValaExpression* value)
 {
+	ValaExpression* __temp2;
+	ValaExpression* __temp1;
 	g_return_if_fail (VALA_IS_RETURN_STATEMENT (self));
-	ValaExpression* __temp2 = NULL;
-	ValaExpression* __temp1 = NULL;
+	__temp2 = NULL;
+	__temp1 = NULL;
 	self->priv->_return_expression = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL))), __temp2);
 	if (self->priv->_return_expression != NULL) {
 		(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_expression), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_return_expression)));
@@ -107,7 +114,8 @@ void vala_return_statement_set_return_expression (ValaReturnStatement* self, Val
 
 static void vala_return_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaReturnStatement * self = VALA_RETURN_STATEMENT (object);
+	ValaReturnStatement * self;
+	self = VALA_RETURN_STATEMENT (object);
 	switch (property_id) {
 		case VALA_RETURN_STATEMENT_RETURN_EXPRESSION:
 		g_value_set_object (value, vala_return_statement_get_return_expression (self));
@@ -118,7 +126,8 @@ static void vala_return_statement_get_property (GObject * object, guint property
 
 static void vala_return_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaReturnStatement * self = VALA_RETURN_STATEMENT (object);
+	ValaReturnStatement * self;
+	self = VALA_RETURN_STATEMENT (object);
 	switch (property_id) {
 		case VALA_RETURN_STATEMENT_RETURN_EXPRESSION:
 		vala_return_statement_set_return_expression (self, g_value_get_object (value));
@@ -148,10 +157,11 @@ static void vala_return_statement_init (ValaReturnStatement * self)
 
 static void vala_return_statement_dispose (GObject * obj)
 {
-	ValaReturnStatement * self = VALA_RETURN_STATEMENT (obj);
-	(self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL)));
+	ValaReturnStatement * self;
 	ValaReturnStatementClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_RETURN_STATEMENT (obj);
+	(self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL)));
 	klass = VALA_RETURN_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_RETURN_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
