@@ -67,6 +67,8 @@ static void vala_symbol_builder_real_visit_property_accessor (ValaCodeVisitor* b
 static void vala_symbol_builder_real_visit_signal (ValaCodeVisitor* base, ValaSignal* sig);
 static void vala_symbol_builder_real_visit_constructor (ValaCodeVisitor* base, ValaConstructor* c);
 static void vala_symbol_builder_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d);
+static void vala_symbol_builder_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt);
+static void vala_symbol_builder_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause);
 static void vala_symbol_builder_real_visit_begin_block (ValaCodeVisitor* base, ValaBlock* b);
 static void vala_symbol_builder_real_visit_end_block (ValaCodeVisitor* base, ValaBlock* b);
 static void vala_symbol_builder_real_visit_type_parameter (ValaCodeVisitor* base, ValaTypeParameter* p);
@@ -762,6 +764,24 @@ static void vala_symbol_builder_real_visit_destructor (ValaCodeVisitor* base, Va
 }
 
 
+static void vala_symbol_builder_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt)
+{
+	ValaSymbolBuilder * self;
+	self = VALA_SYMBOL_BUILDER (base);
+	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_symbol_builder_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause)
+{
+	ValaSymbolBuilder * self;
+	self = VALA_SYMBOL_BUILDER (base);
+	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
+	vala_code_node_accept_children (VALA_CODE_NODE (clause), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_symbol_builder_real_visit_begin_block (ValaCodeVisitor* base, ValaBlock* b)
 {
 	ValaSymbolBuilder * self;
@@ -827,6 +847,8 @@ static void vala_symbol_builder_class_init (ValaSymbolBuilderClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_signal = vala_symbol_builder_real_visit_signal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_constructor = vala_symbol_builder_real_visit_constructor;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_destructor = vala_symbol_builder_real_visit_destructor;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_symbol_builder_real_visit_try_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_symbol_builder_real_visit_catch_clause;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_block = vala_symbol_builder_real_visit_begin_block;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_end_block = vala_symbol_builder_real_visit_end_block;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_type_parameter = vala_symbol_builder_real_visit_type_parameter;
