@@ -62,6 +62,9 @@ static void vala_symbol_resolver_real_visit_constructor (ValaCodeVisitor* base,
 static void vala_symbol_resolver_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d);
 static void vala_symbol_resolver_real_visit_namespace_reference (ValaCodeVisitor* base, ValaNamespaceReference* ns);
 static void vala_symbol_resolver_real_visit_type_reference (ValaCodeVisitor* base, ValaTypeReference* type);
+static void vala_symbol_resolver_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt);
+static void vala_symbol_resolver_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt);
+static void vala_symbol_resolver_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause);
 static gpointer vala_symbol_resolver_parent_class = NULL;
 static void vala_symbol_resolver_dispose (GObject * obj);
 
@@ -575,6 +578,33 @@ static void vala_symbol_resolver_real_visit_type_reference (ValaCodeVisitor* bas
 }
 
 
+static void vala_symbol_resolver_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt)
+{
+	ValaSymbolResolver * self;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (VALA_IS_THROW_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_symbol_resolver_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt)
+{
+	ValaSymbolResolver * self;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_symbol_resolver_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause)
+{
+	ValaSymbolResolver * self;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
+	vala_code_node_accept_children (VALA_CODE_NODE (clause), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_symbol_resolver_class_init (ValaSymbolResolverClass * klass)
 {
 	vala_symbol_resolver_parent_class = g_type_class_peek_parent (klass);
@@ -599,6 +629,9 @@ static void vala_symbol_resolver_class_init (ValaSymbolResolverClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_destructor = vala_symbol_resolver_real_visit_destructor;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_namespace_reference = vala_symbol_resolver_real_visit_namespace_reference;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_type_reference = vala_symbol_resolver_real_visit_type_reference;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_throw_statement = vala_symbol_resolver_real_visit_throw_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_symbol_resolver_real_visit_try_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_symbol_resolver_real_visit_catch_clause;
 }
 
 
