@@ -32,10 +32,23 @@
 #include <vala/valaclass.h>
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
+#include <vala/valaenum.h>
 #include <vala/valacallback.h>
+#include <vala/valaconstant.h>
+#include <vala/valafield.h>
+#include <vala/valamethod.h>
+#include <vala/valacreationmethod.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valaproperty.h>
+#include <vala/valapropertyaccessor.h>
+#include <vala/valasignal.h>
+#include <vala/valaconstructor.h>
+#include <vala/valadestructor.h>
 #include <vala/valanamespacereference.h>
 #include <vala/valatypereference.h>
+#include <vala/valathrowstatement.h>
+#include <vala/valatrystatement.h>
+#include <vala/valacatchclause.h>
 
 G_BEGIN_DECLS
 
